@@ -13,13 +13,14 @@ var branchesQuery struct {
 			Nodes []struct {
 				Name   githubv4.String
 				Target struct {
-					Commit QLCommit `graphql:"... on Commit"`
+					Commit qlCommit `graphql:"... on Commit"`
 				}
 			}
 		} `graphql:"refs(first: 100, refPrefix: \"refs/heads/\")"`
 	} `graphql:"repository(owner: $owner, name: $name)"`
 }
 
+// Branches returns a list of branches for the given repository.
 func (c *Client) Branches(owner string, name string) ([]vcs.Branch, error) {
 	variables := map[string]interface{}{
 		"owner": githubv4.String(owner),
@@ -34,7 +35,7 @@ func (c *Client) Branches(owner string, name string) ([]vcs.Branch, error) {
 	for _, node := range branchesQuery.Repository.Refs.Nodes {
 		branches = append(branches, vcs.Branch{
 			Name:       string(node.Name),
-			LastCommit: CommitFromQL(node.Target.Commit),
+			LastCommit: commitFromQL(node.Target.Commit),
 		})
 	}
 
